@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-import anydbm, errno, md5, os, stat, struct, sys
+import bsddb, errno, md5, os, stat, struct, sys
 
 from cPickle import dumps, loads
 
@@ -42,13 +42,13 @@ def dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, MAXSIZE, PROFILE
 
     tempd = fileutil.NamedTemporaryDirectory()
     db1fname = os.path.join(tempd.name, TMPDB1FNAME)
-    d1 = anydbm.open(db1fname, "n")
+    d1 = bsddb.btopen(db1fname, "n")
     tempd.register_file(d1)
     fileutil.remove_if_possible(db1fname)
     db2fname = os.path.join(tempd.name, TMPDB2FNAME)
-    d2 = anydbm.open(db2fname, "n")
-    fileutil.remove_if_possible(db2fname)
+    d2 = bsddb.btopen(db2fname, "n")
     tempd.register_file(d2)
+    fileutil.remove_if_possible(db2fname)
     try:
         return _dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, MAXSIZE, PROFILES, INCLUDE_NAMES_IN_PROFILES, NOFOLLOWSYMLINKS, DIRS, WINDOWS, d1, d2)
     finally:
@@ -198,10 +198,10 @@ def _dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, MAXSIZE, PROFIL
                         d4v.add(onename)
                         d4[d4k] = d4v
                     for (iterdevino, iterfnames) in d4.iteritems():
-                        if PROFILES:
+                        if PROFILES and not INCLUDE_NAMES_IN_PROFILES:
                             print "identical; md5: %s, size: %s" % (md5h, size)
-                        else:
-                            print "md5: %s, size: %s, fnames: %s" % (md5h, size, iterfnames,)
+                        elif not PROFILES or INCLUDE_NAMES_IN_PROFILES:
+                            print "identical; md5: %s, size: %s, fnames: %s" % (md5h, size, iterfnames,)
                         if HARDLINKEM or DELETEEM:
                             for fname in iterfnames:
                                 if fname != onename:
